@@ -1,3 +1,3 @@
 from .client_platform import require_client_platform
-from .rbac_voter import require_role, is_practice_dependant_role
+from .rbac_voter import require_role
 from .user_dependant import require_user
